/****************************************************************************
*                                                                           *
*                  ___  ____  ____   ___  __    ____  ____                  *
*                 / __)(_  _)(  _ \ / __)(  )  ( ___)(  _ \                 *
*                ( (__  _)(_  )   /( (__  )(__  )__)  )(_) )                *
*                 \___)(____)(_)\_) \___)(____)(____)(____/                 *
*                                                                           *
*                                                                           *
*                                                                           *
*   This file is part of Circled                                            *
*                                                                           *
*   Copyright (C) 2011  Fabien LOISON                                       *
*                                                                           *
*   Circled is free software: you can redistribute it and/or modify         *
*   it under the terms of the GNU General Public License as published by    *
*   the Free Software Foundation, either version 3 of the License, or       *
*   (at your option) any later version.                                     *
*                                                                           *
*   This program is distributed in the hope that it will be useful,         *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of          *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           *
*   GNU General Public License for more details.                            *
*                                                                           *
*   You should have received a copy of the GNU General Public License       *
*   along with this program.  If not, see <http://www.gnu.org/licenses/>.   *
*                                                                           *
****************************************************************************/


#ifndef TERMUI_H_INCLUDED
#define TERMUI_H_INCLUDED


#define MOUSE_MASK 0xE7 //11100111
#define MOUSE_DOWN 0x20 //00100000
#define MOUSE_UP   0x23 //00100011

#define EV_TYPE_NONE     0x00 //Not implemented
#define EV_TYPE_CHAR     0x01 //Simple char
#define EV_TYPE_KEYBOARD 0x02 //Keyboard special key
#define EV_TYPE_MOUSE    0x03 //Mouse


class Event
{		
	public:
		Event();                    //The contructor
		Event(char input_buff[7]);  //The contructor
		int get_type();
		char get_char();
		char get_mouse_event();
		int get_mouse_pos_x();
		int get_mouse_pos_y();

	private:
		char buff[7];
};


class Terminal
{		
	public:
		Terminal();  //The contructor
		~Terminal(); //The destructor
		int get_width();
		int get_height();
		void set_fg_color(int color);
		void set_bg_color(int color);
		void move_xy(int x, int y);
		void draw_rectangle(int x1, int y1, int x2, int y2);
		void draw_text_rectangle(int x1, int y1, int x2, int y2, char *text);
		void print_xy(int x, int y, char* text);		
		void set_title(char* title);
		Event get_event();

	private:
		termios stored_settings;
};


class MouseEventBox
{
	public:
		MouseEventBox(int x1, int y1, int x2, int y2); //The contructor
		bool check_collide(Event *ev);

	private:
		int coord[4];
};


#endif //TERMUI_H_INCLUDED
